<?php
/**
 * Plugin Name:     LearnDash EDD Integration Plugin
 * Plugin URI:      http://learndash.com
 * Description:     LearnDash integration plugin for EDD
 * Version:         1.0.2
 * Author:          LearnDash
 * Author URI:      http://learndash.com
 * Text Domain:     learndash-edd
 *
 * @package         LearnDash\EDD
 */


// Exit if accessed directly
if( ! defined( 'ABSPATH' ) ) exit;


if( ! class_exists( 'LearnDash_EDD' ) ) {


    /**
     * Main LearnDash_EDD class
     *
     * @since       1.0.0
     */
    class LearnDash_EDD {


        /**
         * @var         LearnDash_EDD $instance The one true LearnDash_EDD
         * @since       1.0.0
         */
        private static $instance;


        /**
         * Get active instance
         *
         * @access      public
         * @since       1.0.0
         * @return      self::$instance The one true LearnDash_EDD
         */
        public static function instance() {
            if( ! self::$instance ) {
                self::$instance = new LearnDash_EDD();
                self::$instance->setup_constants();
                self::$instance->includes();
                self::$instance->load_textdomain();
                self::$instance->hooks();
            }

            return self::$instance;
        }


        /**
         * Setup plugin constants
         *
         * @access      private
         * @since       1.0.0
         * @return      void
         */
        private function setup_constants() {
            // Plugin path
            define( 'LEARNDASH_EDD_DIR', plugin_dir_path( __FILE__ ) );

            // Plugin URL
            define( 'LEARNDASH_EDD_URL', plugin_dir_url( __FILE__ ) );
        }


        /**
         * Include required files
         *
         * @access      private
         * @since       1.0.0
         * @return      void
         */
        private function includes() {
            require_once LEARNDASH_EDD_DIR . 'includes/scripts.php';

            if( is_admin() ) {
                require_once LEARNDASH_EDD_DIR . 'includes/metabox.php';
            }
        }


        /**
         * Run action and filter hooks
         *
         * @access      private
         * @since       1.0.0
         * @return      void
         */
        private function hooks() {
            // Update courses
            add_action( 'edd_updated_edited_purchase', array( $this, 'update_course_access' ) );
            add_action( 'edd_complete_purchase', array( $this, 'update_course_access' ) );
        }


        /**
         * Internationalization
         *
         * @access      public
         * @since       1.0.0
         * @return      void
         */
        public function load_textdomain() {
            // Set filter for language directory
            $lang_dir = dirname( plugin_basename( __FILE__ ) ) . '/languages/';
            $lang_dir = apply_filters( 'learndash_edd_language_directory', $lang_dir );

            // Traditional WordPress plugin locale filter
            $locale = apply_filters( 'plugin_locale', get_locale(), '' );
            $mofile = sprintf( '%1$s-%2$s.mo', 'learndash-edd', $locale );

            // Setup paths to current locale file
            $mofile_local   = $lang_dir . $mofile;
            $mofile_global  = WP_LANG_DIR . '/learndash-edd' . $mofile;

            if( file_exists( $mofile_global ) ) {
                // Look in global /wp-content/languages/learndash-edd/ folder
                load_textdomain( 'learndash-edd', $mofile_global );
            } elseif( file_exists( $mofile_local ) ) {
                // Look in local /wp-content/plugins/learndash-edd/languages/ folder
                load_textdomain( 'learndash-edd', $mofile_local );
            } else {
                // Load the default language files
                load_plugin_textdomain( 'learndash-edd', false, $lang_dir );
            }
        }


        /**
         * Update LearnDash course access
         *
         * @access      public
         * @since       1.0.0
         * @return      void
         */
        public function update_course_access( $transaction_id ) {
            // Get transaction data

            $transaction = get_post( $transaction_id );

            // Get customer ID.
            $customer_id 	= get_post_meta( $transaction_id, '_edd_payment_user_id', true );
			$customer_email = get_post_meta( $transaction_id, '_edd_payment_user_email', true );
			
			if ( !empty( $customer_email ) ) {
			
	            // Get all courses user has access to
	            $purchases = edd_get_users_purchased_products( $customer_email );
	            $authorized_courses = array(); // What is this used for? 

	            if( is_array( $purchases ) ) {
	                foreach( $purchases as $key => $product ) {
	                    $authorized_courses[$key] = $product->ID;

	                    // Check if the purchase is assigned to a course
	                    $is_course = get_post_meta( $product->ID, '_edd_learndash_is_course', true ) ? true : false;
	                    if( $is_course ) {
	                        $courses = get_post_meta( $product->ID, '_edd_learndash_course', true );

	                        if( $courses ) {
	                            foreach( $courses as $key => $course ) {
	                                ld_update_course_access( (int) $customer_id, (int) $course );
	                            }
	                        }
	                    }
	                }
	            }
			} 
        }
    }
}


/**
 * The main function responsible for returning the one true LearnDash_EDD
 * instance to functions everywhere
 *
 * @since       1.0.0
 * @return      LearnDash_EDD The one true LearnDash_EDD
 */
function learndash_edd_load() {
    return LearnDash_EDD::instance();
}
add_action( 'plugins_loaded', 'learndash_edd_load' );
